summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2012-03-02 02:11:27 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2012-03-02 02:11:27 -0600
commit67ac950eb8660dc7f455640ffe77fd36b2fa44af (patch)
tree025f297b116786a8df77f42a264eaec5ec34be94
parent9ba1ac7f1c73233eb133f35babbcbb7f89dabb50 (diff)
downloadtqtinterface-67ac950e.tar.gz
tqtinterface-67ac950e.zip
Undo prior accidental commit
-rw-r--r--qtinterface/interface_qt3/tqapplication.cpp12
-rw-r--r--qtinterface/interface_qt3/tqdir.cpp2
-rw-r--r--qtinterface/interface_qt3/tqmap.h2
-rw-r--r--qtinterface/interface_qt3/tqpaintdevice.cpp4
-rw-r--r--qtinterface/interface_qt3/tqstrlist.h4
-rw-r--r--qtinterface/interface_qt3/tqtextcodec.cpp16
-rw-r--r--qtinterface/interface_qt3/tqvaluelist.h2
-rw-r--r--qtinterface/interface_tqt3/tqapplication.cpp12
-rw-r--r--qtinterface/interface_tqt3/tqdir.cpp2
-rw-r--r--qtinterface/interface_tqt3/tqmap.h2
-rw-r--r--qtinterface/interface_tqt3/tqpaintdevice.cpp4
-rw-r--r--qtinterface/interface_tqt3/tqstrlist.h4
-rw-r--r--qtinterface/interface_tqt3/tqtextcodec.cpp16
-rw-r--r--qtinterface/interface_tqt3/tqvaluelist.h2
-rw-r--r--qtinterface/qt4/Qt/q3header.h2
-rw-r--r--qtinterface/qt4/Qt/q3strlist.h4
-rw-r--r--qtinterface/qt4/Qt/q3strvec.h4
-rw-r--r--qtinterface/qt4/Qt/qbytearray.h20
-rw-r--r--qtinterface/qt4/Qt/qcoreapplication.h4
-rw-r--r--qtinterface/qt4/Qt/qdebug.h16
-rw-r--r--qtinterface/qt4/Qt/qglobal.h60
-rw-r--r--qtinterface/qt4/Qt/qmacdefines_mac.h10
-rw-r--r--qtinterface/qt4/Qt/qmessagebox.h6
-rw-r--r--qtinterface/qt4/Qt/qsignalspy.h8
-rw-r--r--qtinterface/qt4/Qt/qtest.h34
-rw-r--r--qtinterface/qt4/Qt/qtestaccessible.h10
-rw-r--r--qtinterface/tqt.h.cmake126
-rw-r--r--qtinterface/tqt4/Qt/qbytearray.h20
-rw-r--r--qtinterface/tqt4/Qt/qglobal.h60
-rw-r--r--qtinterface/tqt4/Qt/qpaintdevice.h2
30 files changed, 235 insertions, 235 deletions
diff --git a/qtinterface/interface_qt3/tqapplication.cpp b/qtinterface/interface_qt3/tqapplication.cpp
index 94da336..26a20d6 100644
--- a/qtinterface/interface_qt3/tqapplication.cpp
+++ b/qtinterface/interface_qt3/tqapplication.cpp
@@ -25,23 +25,23 @@ Boston, MA 02110-1301, USA.
#include <X11/X.h>
#ifdef USE_QT3
-extern Time tqt_x_time;
-extern Time tqt_x_user_time;
+extern Time qt_x_time;
+extern Time qt_x_user_time;
void set_tqt_x_time(unsigned long x) {
- tqt_x_time = x;
+ qt_x_time = x;
}
unsigned long get_tqt_x_time(void) {
- return tqt_x_time;
+ return qt_x_time;
}
void set_tqt_x_user_time(unsigned long x) {
- tqt_x_user_time = x;
+ qt_x_user_time = x;
}
unsigned long get_tqt_x_user_time(void) {
- return tqt_x_user_time;
+ return qt_x_user_time;
}
#endif
diff --git a/qtinterface/interface_qt3/tqdir.cpp b/qtinterface/interface_qt3/tqdir.cpp
index 55328d1..328148e 100644
--- a/qtinterface/interface_qt3/tqdir.cpp
+++ b/qtinterface/interface_qt3/tqdir.cpp
@@ -28,7 +28,7 @@ bool QDir::exists( const QString &name, bool acceptAbsPath )
{
if ( name.isEmpty() ) {
#if defined(QT_CHECK_NULL)
- tqWarning( "QDir::exists: Empty or null file name" );
+ qWarning( "QDir::exists: Empty or null file name" );
#endif
return FALSE;
}
diff --git a/qtinterface/interface_qt3/tqmap.h b/qtinterface/interface_qt3/tqmap.h
index f33b2c1..58ccd40 100644
--- a/qtinterface/interface_qt3/tqmap.h
+++ b/qtinterface/interface_qt3/tqmap.h
@@ -604,7 +604,7 @@ Q_TYPENAME TQMapPrivate<Key,T>::Iterator TQMapPrivate<Key,T>::insert( TQMapNodeB
#ifdef QT_CHECK_RANGE
# if !defined( QT_NO_DEBUG ) && defined( QT_CHECK_MAP_RANGE )
-# define QT_CHECK_INVALID_MAP_ELEMENT if ( empty() ) tqWarning( "TQMap: Warning invalid element" )
+# define QT_CHECK_INVALID_MAP_ELEMENT if ( empty() ) qWarning( "TQMap: Warning invalid element" )
# define QT_CHECK_INVALID_MAP_ELEMENT_FATAL Q_ASSERT( !empty() );
# else
# define QT_CHECK_INVALID_MAP_ELEMENT
diff --git a/qtinterface/interface_qt3/tqpaintdevice.cpp b/qtinterface/interface_qt3/tqpaintdevice.cpp
index d5806e1..846342a 100644
--- a/qtinterface/interface_qt3/tqpaintdevice.cpp
+++ b/qtinterface/interface_qt3/tqpaintdevice.cpp
@@ -95,11 +95,11 @@ static GC create_gc( int scrn, bool monochrome )
return gc;
}
-GC tqt_xget_temp_gc( int scrn, bool monochrome ) // get temporary GC
+GC qt_xget_temp_gc( int scrn, bool monochrome ) // get temporary GC
{
int appScreenCount = QApplication::desktop()->numScreens();
if ( scrn < 0 || scrn >= appScreenCount ) {
- tqDebug("invalid screen (tmp) %d %d", scrn, appScreenCount );
+ qDebug("invalid screen (tmp) %d %d", scrn, appScreenCount );
QWidget* bla = 0;
bla->setName("hello");
}
diff --git a/qtinterface/interface_qt3/tqstrlist.h b/qtinterface/interface_qt3/tqstrlist.h
index bfa621d..9967457 100644
--- a/qtinterface/interface_qt3/tqstrlist.h
+++ b/qtinterface/interface_qt3/tqstrlist.h
@@ -149,7 +149,7 @@ public:
}
private:
- Q3PtrCollection::Item newItem( Q3PtrCollection::Item d ) { return dc ? tqstrdup( (const char*)d ) : d; }
+ Q3PtrCollection::Item newItem( Q3PtrCollection::Item d ) { return dc ? qstrdup( (const char*)d ) : d; }
void deleteItem( Q3PtrCollection::Item d ) { if ( del_item ) delete[] (char*)d; }
int compareItems( Q3PtrCollection::Item s1, Q3PtrCollection::Item s2 ) { return qstrcmp((const char*)s1,
(const char*)s2); }
@@ -170,7 +170,7 @@ public:
~TQStrIList() { clear(); }
private:
int compareItems( Q3PtrCollection::Item s1, Q3PtrCollection::Item s2 )
- { return tqstricmp((const char*)s1,
+ { return qstricmp((const char*)s1,
(const char*)s2); }
};
diff --git a/qtinterface/interface_qt3/tqtextcodec.cpp b/qtinterface/interface_qt3/tqtextcodec.cpp
index 812e7ba..6e047a5 100644
--- a/qtinterface/interface_qt3/tqtextcodec.cpp
+++ b/qtinterface/interface_qt3/tqtextcodec.cpp
@@ -128,15 +128,15 @@ public:
char comm='%';
bool incmap = FALSE;
while (iod->readLine(line,maxlen) > 0) {
- if (0==tqstrnicmp(line,"<code_set_name>",15))
+ if (0==qstrnicmp(line,"<code_set_name>",15))
n = line+15;
- else if (0==tqstrnicmp(line,"<escape_char> ",14))
+ else if (0==qstrnicmp(line,"<escape_char> ",14))
esc = line[14];
- else if (0==tqstrnicmp(line,"<comment_char> ",15))
+ else if (0==qstrnicmp(line,"<comment_char> ",15))
comm = line[15];
- else if (line[0]==comm && 0==tqstrnicmp(line+1," alias ",7)) {
+ else if (line[0]==comm && 0==qstrnicmp(line+1," alias ",7)) {
aliases.append(line+8);
- } else if (0==tqstrnicmp(line,"CHARMAP",7)) {
+ } else if (0==qstrnicmp(line,"CHARMAP",7)) {
if (!from_unicode_page) {
from_unicode_page = new char*[256];
for (int i=0; i<256; i++)
@@ -146,7 +146,7 @@ public:
to_unicode = new ushort[256];
}
incmap = TRUE;
- } else if (0==tqstrnicmp(line,"END CHARMAP",11))
+ } else if (0==qstrnicmp(line,"END CHARMAP",11))
break;
else if (incmap) {
char* cursor = line;
@@ -226,7 +226,7 @@ public:
}
mb[nmb++] = 0;
from_unicode_page_multiByte[ch.row()][ch.cell()]
- = tqstrdup(mb);
+ = qstrdup(mb);
*mb_unicode = unicode;
} else {
from_unicode_page[ch.row()][ch.cell()] = (char)byte;
@@ -492,7 +492,7 @@ int QTextCodec::heuristicNameMatch(const char* hint) const
int QTextCodec::simpleHeuristicNameMatch(const char* name, const char* hint)
{
// if they're the same, return a perfect score.
- if ( name && hint && *name && *hint && tqstricmp( name, hint ) == 0 )
+ if ( name && hint && *name && *hint && qstricmp( name, hint ) == 0 )
return qstrlen( hint );
// if the letters and numbers are the same, we have an "almost"
diff --git a/qtinterface/interface_qt3/tqvaluelist.h b/qtinterface/interface_qt3/tqvaluelist.h
index 2ae9d55..f8d73b9 100644
--- a/qtinterface/interface_qt3/tqvaluelist.h
+++ b/qtinterface/interface_qt3/tqvaluelist.h
@@ -423,7 +423,7 @@ void TQValueListPrivate<T>::clear()
#ifdef QT_CHECK_RANGE
# if !defined( QT_NO_DEBUG ) && defined( QT_CHECK_VALUELIST_RANGE )
-# define QT_CHECK_INVALID_LIST_ELEMENT if ( empty() ) tqWarning( "TQValueList: Warning invalid element" )
+# define QT_CHECK_INVALID_LIST_ELEMENT if ( empty() ) qWarning( "TQValueList: Warning invalid element" )
# define QT_CHECK_INVALID_LIST_ELEMENT_FATAL Q_ASSERT( !empty() );
# else
# define QT_CHECK_INVALID_LIST_ELEMENT
diff --git a/qtinterface/interface_tqt3/tqapplication.cpp b/qtinterface/interface_tqt3/tqapplication.cpp
index dbeef36..d96d9fc 100644
--- a/qtinterface/interface_tqt3/tqapplication.cpp
+++ b/qtinterface/interface_tqt3/tqapplication.cpp
@@ -25,23 +25,23 @@ Boston, MA 02110-1301, USA.
#include <X11/X.h>
#ifdef USE_QT3
-extern Time tqt_x_time;
-extern Time tqt_x_user_time;
+extern Time qt_x_time;
+extern Time qt_x_user_time;
void set_tqt_x_time(unsigned long x) {
- tqt_x_time = x;
+ qt_x_time = x;
}
unsigned long get_tqt_x_time(void) {
- return tqt_x_time;
+ return qt_x_time;
}
void set_tqt_x_user_time(unsigned long x) {
- tqt_x_user_time = x;
+ qt_x_user_time = x;
}
unsigned long get_tqt_x_user_time(void) {
- return tqt_x_user_time;
+ return qt_x_user_time;
}
#endif
diff --git a/qtinterface/interface_tqt3/tqdir.cpp b/qtinterface/interface_tqt3/tqdir.cpp
index 5b5f7c9..f75503d 100644
--- a/qtinterface/interface_tqt3/tqdir.cpp
+++ b/qtinterface/interface_tqt3/tqdir.cpp
@@ -28,7 +28,7 @@ bool QDir::exists( const QString &name, bool acceptAbsPath )
{
if ( name.isEmpty() ) {
#if defined(QT_CHECK_NULL)
- tqWarning( "QDir::exists: Empty or null file name" );
+ qWarning( "QDir::exists: Empty or null file name" );
#endif
return FALSE;
}
diff --git a/qtinterface/interface_tqt3/tqmap.h b/qtinterface/interface_tqt3/tqmap.h
index 6bdb42d..b5f89ae 100644
--- a/qtinterface/interface_tqt3/tqmap.h
+++ b/qtinterface/interface_tqt3/tqmap.h
@@ -604,7 +604,7 @@ Q_TYPENAME TQMapPrivate<Key,T>::Iterator TQMapPrivate<Key,T>::insert( TQMapNodeB
#ifdef QT_CHECK_RANGE
# if !defined( QT_NO_DEBUG ) && defined( QT_CHECK_MAP_RANGE )
-# define QT_CHECK_INVALID_MAP_ELEMENT if ( empty() ) tqWarning( "TQMap: Warning invalid element" )
+# define QT_CHECK_INVALID_MAP_ELEMENT if ( empty() ) qWarning( "TQMap: Warning invalid element" )
# define QT_CHECK_INVALID_MAP_ELEMENT_FATAL Q_ASSERT( !empty() );
# else
# define QT_CHECK_INVALID_MAP_ELEMENT
diff --git a/qtinterface/interface_tqt3/tqpaintdevice.cpp b/qtinterface/interface_tqt3/tqpaintdevice.cpp
index 103d845..0ebab87 100644
--- a/qtinterface/interface_tqt3/tqpaintdevice.cpp
+++ b/qtinterface/interface_tqt3/tqpaintdevice.cpp
@@ -95,11 +95,11 @@ static GC create_gc( int scrn, bool monochrome )
return gc;
}
-GC tqt_xget_temp_gc( int scrn, bool monochrome ) // get temporary GC
+GC qt_xget_temp_gc( int scrn, bool monochrome ) // get temporary GC
{
int appScreenCount = QApplication::desktop()->numScreens();
if ( scrn < 0 || scrn >= appScreenCount ) {
- tqDebug("invalid screen (tmp) %d %d", scrn, appScreenCount );
+ qDebug("invalid screen (tmp) %d %d", scrn, appScreenCount );
QWidget* bla = 0;
bla->setName("hello");
}
diff --git a/qtinterface/interface_tqt3/tqstrlist.h b/qtinterface/interface_tqt3/tqstrlist.h
index bedc6b7..ac0abc7 100644
--- a/qtinterface/interface_tqt3/tqstrlist.h
+++ b/qtinterface/interface_tqt3/tqstrlist.h
@@ -149,7 +149,7 @@ public:
}
private:
- Q3PtrCollection::Item newItem( Q3PtrCollection::Item d ) { return dc ? tqstrdup( (const char*)d ) : d; }
+ Q3PtrCollection::Item newItem( Q3PtrCollection::Item d ) { return dc ? qstrdup( (const char*)d ) : d; }
void deleteItem( Q3PtrCollection::Item d ) { if ( del_item ) delete[] (char*)d; }
int compareItems( Q3PtrCollection::Item s1, Q3PtrCollection::Item s2 ) { return qstrcmp((const char*)s1,
(const char*)s2); }
@@ -170,7 +170,7 @@ public:
~TQStrIList() { clear(); }
private:
int compareItems( Q3PtrCollection::Item s1, Q3PtrCollection::Item s2 )
- { return tqstricmp((const char*)s1,
+ { return qstricmp((const char*)s1,
(const char*)s2); }
};
diff --git a/qtinterface/interface_tqt3/tqtextcodec.cpp b/qtinterface/interface_tqt3/tqtextcodec.cpp
index 6bb5b72..2333405 100644
--- a/qtinterface/interface_tqt3/tqtextcodec.cpp
+++ b/qtinterface/interface_tqt3/tqtextcodec.cpp
@@ -128,15 +128,15 @@ public:
char comm='%';
bool incmap = FALSE;
while (iod->readLine(line,maxlen) > 0) {
- if (0==tqstrnicmp(line,"<code_set_name>",15))
+ if (0==qstrnicmp(line,"<code_set_name>",15))
n = line+15;
- else if (0==tqstrnicmp(line,"<escape_char> ",14))
+ else if (0==qstrnicmp(line,"<escape_char> ",14))
esc = line[14];
- else if (0==tqstrnicmp(line,"<comment_char> ",15))
+ else if (0==qstrnicmp(line,"<comment_char> ",15))
comm = line[15];
- else if (line[0]==comm && 0==tqstrnicmp(line+1," alias ",7)) {
+ else if (line[0]==comm && 0==qstrnicmp(line+1," alias ",7)) {
aliases.append(line+8);
- } else if (0==tqstrnicmp(line,"CHARMAP",7)) {
+ } else if (0==qstrnicmp(line,"CHARMAP",7)) {
if (!from_unicode_page) {
from_unicode_page = new char*[256];
for (int i=0; i<256; i++)
@@ -146,7 +146,7 @@ public:
to_unicode = new ushort[256];
}
incmap = TRUE;
- } else if (0==tqstrnicmp(line,"END CHARMAP",11))
+ } else if (0==qstrnicmp(line,"END CHARMAP",11))
break;
else if (incmap) {
char* cursor = line;
@@ -226,7 +226,7 @@ public:
}
mb[nmb++] = 0;
from_unicode_page_multiByte[ch.row()][ch.cell()]
- = tqstrdup(mb);
+ = qstrdup(mb);
*mb_unicode = unicode;
} else {
from_unicode_page[ch.row()][ch.cell()] = (char)byte;
@@ -492,7 +492,7 @@ int QTextCodec::heuristicNameMatch(const char* hint) const
int QTextCodec::simpleHeuristicNameMatch(const char* name, const char* hint)
{
// if they're the same, return a perfect score.
- if ( name && hint && *name && *hint && tqstricmp( name, hint ) == 0 )
+ if ( name && hint && *name && *hint && qstricmp( name, hint ) == 0 )
return qstrlen( hint );
// if the letters and numbers are the same, we have an "almost"
diff --git a/qtinterface/interface_tqt3/tqvaluelist.h b/qtinterface/interface_tqt3/tqvaluelist.h
index 63b3278..b8e1241 100644
--- a/qtinterface/interface_tqt3/tqvaluelist.h
+++ b/qtinterface/interface_tqt3/tqvaluelist.h
@@ -423,7 +423,7 @@ void TQValueListPrivate<T>::clear()
#ifdef QT_CHECK_RANGE
# if !defined( QT_NO_DEBUG ) && defined( QT_CHECK_VALUELIST_RANGE )
-# define QT_CHECK_INVALID_LIST_ELEMENT if ( empty() ) tqWarning( "TQValueList: Warning invalid element" )
+# define QT_CHECK_INVALID_LIST_ELEMENT if ( empty() ) qWarning( "TQValueList: Warning invalid element" )
# define QT_CHECK_INVALID_LIST_ELEMENT_FATAL Q_ASSERT( !empty() );
# else
# define QT_CHECK_INVALID_LIST_ELEMENT
diff --git a/qtinterface/qt4/Qt/q3header.h b/qtinterface/qt4/Qt/q3header.h
index 1ddc7f4..702b59b 100644
--- a/qtinterface/qt4/Qt/q3header.h
+++ b/qtinterface/qt4/Qt/q3header.h
@@ -214,7 +214,7 @@ inline Qt::Orientation Q3Header::orientation() const
inline void Q3Header::setTracking(bool enable) { trackingIsOn = enable; }
inline bool Q3Header::tracking() const { return trackingIsOn; }
-extern Q_COMPAT_EXPORT bool tqt_qheader_label_return_null_strings; // needed for professional edition
+extern Q_COMPAT_EXPORT bool qt_qheader_label_return_null_strings; // needed for professional edition
#endif // QT_NO_HEADER
diff --git a/qtinterface/qt4/Qt/q3strlist.h b/qtinterface/qt4/Qt/q3strlist.h
index e802d1e..91c6a78 100644
--- a/qtinterface/qt4/Qt/q3strlist.h
+++ b/qtinterface/qt4/Qt/q3strlist.h
@@ -88,7 +88,7 @@ public:
}
private:
- Q3PtrCollection::Item newItem( Q3PtrCollection::Item d ) { return dc ? tqstrdup( (const char*)d ) : d; }
+ Q3PtrCollection::Item newItem( Q3PtrCollection::Item d ) { return dc ? qstrdup( (const char*)d ) : d; }
void deleteItem( Q3PtrCollection::Item d ) { if ( del_item ) delete[] (char*)d; }
int compareItems( Q3PtrCollection::Item s1, Q3PtrCollection::Item s2 ) { return qstrcmp((const char*)s1,
(const char*)s2); }
@@ -109,7 +109,7 @@ public:
~Q3StrIList() { clear(); }
private:
int compareItems( Q3PtrCollection::Item s1, Q3PtrCollection::Item s2 )
- { return tqstricmp((const char*)s1,
+ { return qstricmp((const char*)s1,
(const char*)s2); }
};
diff --git a/qtinterface/qt4/Qt/q3strvec.h b/qtinterface/qt4/Qt/q3strvec.h
index 2e74bb6..e66b2d6 100644
--- a/qtinterface/qt4/Qt/q3strvec.h
+++ b/qtinterface/qt4/Qt/q3strvec.h
@@ -59,7 +59,7 @@ public:
Q3StrVec( uint size, bool deepc = true ) : Q3PtrVector<char>(size) {dc=deepc;}
~Q3StrVec() { clear(); }
private:
- Item newItem( Item d ) { return dc ? tqstrdup( (const char*)d ) : d; }
+ Item newItem( Item d ) { return dc ? qstrdup( (const char*)d ) : d; }
void deleteItem( Item d ) { if ( dc ) delete[] (char*)d; }
int compareItems( Item s1, Item s2 )
{ return qstrcmp((const char*)s1,
@@ -82,7 +82,7 @@ public:
~Q3StrIVec() { clear(); }
private:
int compareItems( Item s1, Item s2 )
- { return tqstricmp((const char*)s1,
+ { return qstricmp((const char*)s1,
(const char*)s2); }
};
diff --git a/qtinterface/qt4/Qt/qcoreapplication.h b/qtinterface/qt4/Qt/qcoreapplication.h
index e624f90..e1adece 100644
--- a/qtinterface/qt4/Qt/qcoreapplication.h
+++ b/qtinterface/qt4/Qt/qcoreapplication.h
@@ -265,8 +265,8 @@ private:
typedef void (*QtCleanUpFunction)();
-Q_CORE_EXPORT void tqAddPostRoutine(QtCleanUpFunction);
-Q_CORE_EXPORT void tqRemovePostRoutine(QtCleanUpFunction);
+Q_CORE_EXPORT void qAddPostRoutine(QtCleanUpFunction);
+Q_CORE_EXPORT void qRemovePostRoutine(QtCleanUpFunction);
Q_CORE_EXPORT QString qAppName(); // get application name
#if defined(Q_WS_WIN) && !defined(QT_NO_DEBUG_STREAM)
diff --git a/qtinterface/qt4/Qt/qdebug.h b/qtinterface/qt4/Qt/qdebug.h
index fc7887e..d788589 100644
--- a/qtinterface/qt4/Qt/qdebug.h
+++ b/qtinterface/qt4/Qt/qdebug.h
@@ -255,12 +255,12 @@ inline QDebug operator<<(QDebug debug, const QContiguousCache<T> &cache)
}
#if !defined(QT_NO_DEBUG_STREAM)
-Q_CORE_EXPORT_INLINE QDebug tqDebug() { return QDebug(QtDebugMsg); }
+Q_CORE_EXPORT_INLINE QDebug qDebug() { return QDebug(QtDebugMsg); }
#else // QT_NO_DEBUG_STREAM
-#undef tqDebug
-inline QNoDebug tqDebug() { return QNoDebug(); }
-#define tqDebug QT_NO_QDEBUG_MACRO
+#undef qDebug
+inline QNoDebug qDebug() { return QNoDebug(); }
+#define qDebug QT_NO_QDEBUG_MACRO
#ifdef QT_NO_MEMBER_TEMPLATES
template<typename T>
@@ -270,11 +270,11 @@ inline QNoDebug operator<<(QNoDebug debug, const T &) { return debug; }
#endif
#if !defined(QT_NO_WARNING_OUTPUT)
-Q_CORE_EXPORT_INLINE QDebug tqWarning() { return QDebug(QtWarningMsg); }
+Q_CORE_EXPORT_INLINE QDebug qWarning() { return QDebug(QtWarningMsg); }
#else
-#undef tqWarning
-inline QNoDebug tqWarning() { return QNoDebug(); }
-#define tqWarning QT_NO_QWARNING_MACRO
+#undef qWarning
+inline QNoDebug qWarning() { return QNoDebug(); }
+#define qWarning QT_NO_QWARNING_MACRO
#endif
QT_END_NAMESPACE
diff --git a/qtinterface/qt4/Qt/qglobal.h b/qtinterface/qt4/Qt/qglobal.h
index ce0db11..9b647a9 100644
--- a/qtinterface/qt4/Qt/qglobal.h
+++ b/qtinterface/qt4/Qt/qglobal.h
@@ -488,7 +488,7 @@ namespace QT_NAMESPACE {}
# if __GNUC__ < 3 || (__GNUC__ == 3 && __GNUC_MINOR__ <= 3)
# define Q_NO_TEMPLATE_FRIENDS
# endif
-/* Apple's GCC 3.1 chokes on our streaming tqDebug() */
+/* Apple's GCC 3.1 chokes on our streaming qDebug() */
# if defined(Q_OS_DARWIN) && __GNUC__ == 3 && (__GNUC_MINOR__ >= 1 && __GNUC_MINOR__ < 3)
# define Q_BROKEN_DEBUG_STREAM
# endif
@@ -1522,15 +1522,15 @@ public:
#endif
};
-Q_CORE_EXPORT const char *tqVersion();
-Q_CORE_EXPORT bool tqSharedBuild();
+Q_CORE_EXPORT const char *qVersion();
+Q_CORE_EXPORT bool qSharedBuild();
#if defined(Q_OS_MAC)
inline int qMacVersion() { return QSysInfo::MacintoshVersion; }
#endif
#ifdef QT3_SUPPORT
-inline QT3_SUPPORT bool tqSysInfo(int *wordSize, bool *bigEndian)
+inline QT3_SUPPORT bool qSysInfo(int *wordSize, bool *bigEndian)
{
*wordSize = QSysInfo::WordSize;
*bigEndian = (QSysInfo::ByteOrder == QSysInfo::BigEndian);
@@ -1593,13 +1593,13 @@ inline void qUnused(T &x) { (void)x; }
# define qPrintable(string) (string).toLocal8Bit().constData()
#endif
-Q_CORE_EXPORT void tqDebug(const char *, ...) /* print debug message */
+Q_CORE_EXPORT void qDebug(const char *, ...) /* print debug message */
#if defined(Q_CC_GNU) && !defined(__INSURE__)
__attribute__ ((format (printf, 1, 2)))
#endif
;
-Q_CORE_EXPORT void tqWarning(const char *, ...) /* print warning message */
+Q_CORE_EXPORT void qWarning(const char *, ...) /* print warning message */
#if defined(Q_CC_GNU) && !defined(__INSURE__)
__attribute__ ((format (printf, 1, 2)))
#endif
@@ -1612,14 +1612,14 @@ Q_CORE_EXPORT void qCritical(const char *, ...) /* print critical message */
__attribute__ ((format (printf, 1, 2)))
#endif
;
-Q_CORE_EXPORT void tqFatal(const char *, ...) /* print fatal message and exit */
+Q_CORE_EXPORT void qFatal(const char *, ...) /* print fatal message and exit */
#if defined(Q_CC_GNU) && !defined(__INSURE__)
__attribute__ ((format (printf, 1, 2)))
#endif
;
#ifdef QT3_SUPPORT
-Q_CORE_EXPORT QT3_SUPPORT void tqSystemWarning(const char *msg, int code = -1);
+Q_CORE_EXPORT QT3_SUPPORT void qSystemWarning(const char *msg, int code = -1);
#endif /* QT3_SUPPORT */
Q_CORE_EXPORT void qErrnoWarning(int code, const char *msg, ...);
Q_CORE_EXPORT void qErrnoWarning(const char *msg, ...);
@@ -1631,25 +1631,25 @@ Q_CORE_EXPORT void qErrnoWarning(const char *msg, ...);
/*
Forward declarations only.
- In order to use the tqDebug() stream, you must #include<QDebug>
+ In order to use the qDebug() stream, you must #include<QDebug>
*/
class QDebug;
class QNoDebug;
#ifndef QT_NO_DEBUG_STREAM
-Q_CORE_EXPORT_INLINE QDebug tqDebug();
-Q_CORE_EXPORT_INLINE QDebug tqWarning();
+Q_CORE_EXPORT_INLINE QDebug qDebug();
+Q_CORE_EXPORT_INLINE QDebug qWarning();
Q_CORE_EXPORT_INLINE QDebug qCritical();
#else
-inline QNoDebug tqDebug();
+inline QNoDebug qDebug();
#endif
-#define QT_NO_QDEBUG_MACRO while (false) tqDebug
+#define QT_NO_QDEBUG_MACRO while (false) qDebug
#ifdef QT_NO_DEBUG_OUTPUT
-# define tqDebug QT_NO_QDEBUG_MACRO
+# define qDebug QT_NO_QDEBUG_MACRO
#endif
-#define QT_NO_QWARNING_MACRO while (false) tqWarning
+#define QT_NO_QWARNING_MACRO while (false) qWarning
#ifdef QT_NO_WARNING_OUTPUT
-# define tqWarning QT_NO_QWARNING_MACRO
+# define qWarning QT_NO_QWARNING_MACRO
#endif
@@ -1677,7 +1677,7 @@ Q_CORE_EXPORT void qt_assert_x(const char *where, const char *what, const char *
# endif
#endif
-Q_CORE_EXPORT void tqt_check_pointer(const char *, int);
+Q_CORE_EXPORT void qt_check_pointer(const char *, int);
#ifndef QT_NO_EXCEPTIONS
Q_CORE_EXPORT void qBadAlloc();
@@ -1687,7 +1687,7 @@ Q_CORE_EXPORT void qBadAlloc();
# if defined(QT_NO_DEBUG)
# define Q_CHECK_PTR(p) qt_noop();
# else
-# define Q_CHECK_PTR(p) do {if(!(p))tqt_check_pointer(__FILE__,__LINE__);} while (0)
+# define Q_CHECK_PTR(p) do {if(!(p))qt_check_pointer(__FILE__,__LINE__);} while (0)
# endif
#else
# define Q_CHECK_PTR(p) do { if (!(p)) qBadAlloc(); } while (0)
@@ -1731,8 +1731,8 @@ typedef void (*QtMsgHandler)(QtMsgType, const char *);
Q_CORE_EXPORT QtMsgHandler qInstallMsgHandler(QtMsgHandler);
#ifdef QT3_SUPPORT
-inline QT3_SUPPORT void tqSuppressObsoleteWarnings(bool = true) {}
-inline QT3_SUPPORT void tqObsolete(const char *, const char * = 0, const char * = 0) {}
+inline QT3_SUPPORT void qSuppressObsoleteWarnings(bool = true) {}
+inline QT3_SUPPORT void qObsolete(const char *, const char * = 0, const char * = 0) {}
#endif
#if defined(QT_NO_THREAD)
@@ -1941,7 +1941,7 @@ static inline bool qIsNull(float f)
#ifdef Q_FULL_TEMPLATE_INSTANTIATION
# define Q_DUMMY_COMPARISON_OPERATOR(C) \
bool operator==(const C&) const { \
- tqWarning(#C"::operator==(const "#C"&) was called"); \
+ qWarning(#C"::operator==(const "#C"&) was called"); \
return false; \
}
#else
@@ -2403,15 +2403,15 @@ Q_CORE_EXPORT int qrand();
#ifndef QT_PRODUCT_LICENSE
# define QT_PRODUCT_LICENSE QLibraryInfo::licensedProducts()
#endif
-QT3_SUPPORT Q_CORE_EXPORT const char *tqInstallPath();
-QT3_SUPPORT Q_CORE_EXPORT const char *tqInstallPathDocs();
-QT3_SUPPORT Q_CORE_EXPORT const char *tqInstallPathHeaders();
-QT3_SUPPORT Q_CORE_EXPORT const char *tqInstallPathLibs();
-QT3_SUPPORT Q_CORE_EXPORT const char *tqInstallPathBins();
-QT3_SUPPORT Q_CORE_EXPORT const char *tqInstallPathPlugins();
-QT3_SUPPORT Q_CORE_EXPORT const char *tqInstallPathData();
-QT3_SUPPORT Q_CORE_EXPORT const char *tqInstallPathTranslations();
-QT3_SUPPORT Q_CORE_EXPORT const char *tqInstallPathSysconf();
+QT3_SUPPORT Q_CORE_EXPORT const char *qInstallPath();
+QT3_SUPPORT Q_CORE_EXPORT const char *qInstallPathDocs();
+QT3_SUPPORT Q_CORE_EXPORT const char *qInstallPathHeaders();
+QT3_SUPPORT Q_CORE_EXPORT const char *qInstallPathLibs();
+QT3_SUPPORT Q_CORE_EXPORT const char *qInstallPathBins();
+QT3_SUPPORT Q_CORE_EXPORT const char *qInstallPathPlugins();
+QT3_SUPPORT Q_CORE_EXPORT const char *qInstallPathData();
+QT3_SUPPORT Q_CORE_EXPORT const char *qInstallPathTranslations();
+QT3_SUPPORT Q_CORE_EXPORT const char *qInstallPathSysconf();
#endif
#if defined(Q_OS_SYMBIAN)
diff --git a/qtinterface/qt4/Qt/qmacdefines_mac.h b/qtinterface/qt4/Qt/qmacdefines_mac.h
index d5927fe..ecd6872 100644
--- a/qtinterface/qt4/Qt/qmacdefines_mac.h
+++ b/qtinterface/qt4/Qt/qmacdefines_mac.h
@@ -100,9 +100,9 @@ Yes, it is an informative comment ;-)
# undef DEBUG
#endif
#define DEBUG 0
-#ifdef tqDebug
-# define old_qDebug tqDebug
-# undef tqDebug
+#ifdef qDebug
+# define old_qDebug qDebug
+# undef qDebug
#endif
#ifdef __LP64__
@@ -186,7 +186,7 @@ typedef AERecord AppleEvent;
#endif
#ifdef old_qDebug
-# undef tqDebug
-# define tqDebug QT_NO_QDEBUG_MACRO
+# undef qDebug
+# define qDebug QT_NO_QDEBUG_MACRO
# undef old_qDebug
#endif
diff --git a/qtinterface/qt4/Qt/qmessagebox.h b/qtinterface/qt4/Qt/qmessagebox.h
index 77e1e46..d3617b7 100644
--- a/qtinterface/qt4/Qt/qmessagebox.h
+++ b/qtinterface/qt4/Qt/qmessagebox.h
@@ -342,7 +342,7 @@ private:
Q_DECLARE_OPERATORS_FOR_FLAGS(QMessageBox::StandardButtons)
#define QT_REQUIRE_VERSION(argc, argv, str) { QString s = QString::fromLatin1(str);\
-QString sq = QString::fromLatin1(tqVersion()); \
+QString sq = QString::fromLatin1(qVersion()); \
if ((sq.section(QChar::fromLatin1('.'),0,0).toInt()<<16)+\
(sq.section(QChar::fromLatin1('.'),1,1).toInt()<<8)+\
sq.section(QChar::fromLatin1('.'),2,2).toInt()<(s.section(QChar::fromLatin1('.'),0,0).toInt()<<16)+\
@@ -353,8 +353,8 @@ if (!qApp){ \
} \
QString s = QApplication::tr("Executable '%1' requires Qt "\
"%2, found Qt %3.").arg(qAppName()).arg(QString::fromLatin1(\
-str)).arg(QString::fromLatin1(tqVersion())); QMessageBox::critical(0, QApplication::tr(\
-"Incompatible Qt Library Error"), s, QMessageBox::Abort, 0); tqFatal(s.toLatin1().data()); }}
+str)).arg(QString::fromLatin1(qVersion())); QMessageBox::critical(0, QApplication::tr(\
+"Incompatible Qt Library Error"), s, QMessageBox::Abort, 0); qFatal(s.toLatin1().data()); }}
#endif // QT_NO_MESSAGEBOX
diff --git a/qtinterface/qt4/Qt/qsignalspy.h b/qtinterface/qt4/Qt/qsignalspy.h
index fb6af7a..fe36a40 100644
--- a/qtinterface/qt4/Qt/qsignalspy.h
+++ b/qtinterface/qt4/Qt/qsignalspy.h
@@ -72,7 +72,7 @@ public:
Q_ASSERT(aSignal);
if (((aSignal[0] - '0') & 0x03) != QSIGNAL_CODE) {
- tqWarning("QSignalSpy: Not a valid signal, use the SIGNAL macro");
+ qWarning("QSignalSpy: Not a valid signal, use the SIGNAL macro");
return;
}
@@ -80,13 +80,13 @@ public:
const QMetaObject *mo = obj->metaObject();
int sigIndex = mo->indexOfMethod(ba.constData());
if (sigIndex < 0) {
- tqWarning("QSignalSpy: No such signal: '%s'", ba.constData());
+ qWarning("QSignalSpy: No such signal: '%s'", ba.constData());
return;
}
if (!QMetaObject::connect(obj, sigIndex, this, memberOffset,
Qt::DirectConnection, 0)) {
- tqWarning("QSignalSpy: QMetaObject::connect returned false. Unable to connect.");
+ qWarning("QSignalSpy: QMetaObject::connect returned false. Unable to connect.");
return;
}
sig = ba;
@@ -119,7 +119,7 @@ private:
for (int i = 0; i < params.count(); ++i) {
int tp = QMetaType::type(params.at(i).constData());
if (tp == QMetaType::Void)
- tqWarning("Don't know how to handle '%s', use qRegisterMetaType to register it.",
+ qWarning("Don't know how to handle '%s', use qRegisterMetaType to register it.",
params.at(i).constData());
args << tp;
}
diff --git a/qtinterface/qt4/Qt/qtest.h b/qtinterface/qt4/Qt/qtest.h
index 8754a4f..e1ce276 100644
--- a/qtinterface/qt4/Qt/qtest.h
+++ b/qtinterface/qt4/Qt/qtest.h
@@ -72,12 +72,12 @@ namespace QTest
template<> inline char *toString(const QLatin1String &str)
{
- return tqstrdup(str.latin1());
+ return qstrdup(str.latin1());
}
template<> inline char *toString(const QString &str)
{
- return tqstrdup(str.toLatin1().constData());
+ return qstrdup(str.toLatin1().constData());
}
template<> inline char *toString(const QByteArray &ba)
@@ -88,63 +88,63 @@ template<> inline char *toString(const QByteArray &ba)
template<> inline char *toString(const QTime &time)
{
return time.isValid()
- ? tqstrdup(time.toString(QLatin1String("hh:mm:ss.zzz")).toLatin1().constData())
- : tqstrdup("Invalid QTime");
+ ? qstrdup(time.toString(QLatin1String("hh:mm:ss.zzz")).toLatin1().constData())
+ : qstrdup("Invalid QTime");
}
template<> inline char *toString(const QDate &date)
{
return date.isValid()
- ? tqstrdup(date.toString(QLatin1String("yyyy/MM/dd")).toLatin1().constData())
- : tqstrdup("Invalid QDate");
+ ? qstrdup(date.toString(QLatin1String("yyyy/MM/dd")).toLatin1().constData())
+ : qstrdup("Invalid QDate");
}
template<> inline char *toString(const QDateTime &dateTime)
{
return dateTime.isValid()
- ? tqstrdup((dateTime.toString(QLatin1String("yyyy/MM/dd hh:mm:ss.zzz")) +
+ ? qstrdup((dateTime.toString(QLatin1String("yyyy/MM/dd hh:mm:ss.zzz")) +
(dateTime.timeSpec() == Qt::LocalTime ? QLatin1String("[local time]") : QLatin1String("[UTC]"))).toLatin1().constData())
- : tqstrdup("Invalid QDateTime");
+ : qstrdup("Invalid QDateTime");
}
template<> inline char *toString(const QChar &c)
{
- return tqstrdup(QString::fromLatin1("QChar: '%1' (0x%2)").arg(c).arg(QString::number(static_cast<int>(c.unicode()), 16)).toLatin1().constData());
+ return qstrdup(QString::fromLatin1("QChar: '%1' (0x%2)").arg(c).arg(QString::number(static_cast<int>(c.unicode()), 16)).toLatin1().constData());
}
template<> inline char *toString(const QPoint &p)
{
- return tqstrdup(QString::fromLatin1("QPoint(%1,%2)").arg(p.x()).arg(p.y()).toLatin1().constData());
+ return qstrdup(QString::fromLatin1("QPoint(%1,%2)").arg(p.x()).arg(p.y()).toLatin1().constData());
}
template<> inline char *toString(const QSize &s)
{
- return tqstrdup(QString::fromLatin1("QSize(%1x%2)").arg(s.width()).arg(s.height()).toLatin1().constData());
+ return qstrdup(QString::fromLatin1("QSize(%1x%2)").arg(s.width()).arg(s.height()).toLatin1().constData());
}
template<> inline char *toString(const QRect &s)
{
- return tqstrdup(QString::fromLatin1("QRect(%1,%2 %5x%6) (bottomright %3,%4)").arg(s.left()).arg(s.top()).arg(s.right()).arg(s.bottom()).arg(s.width()).arg(s.height()).toLatin1().constData());
+ return qstrdup(QString::fromLatin1("QRect(%1,%2 %5x%6) (bottomright %3,%4)").arg(s.left()).arg(s.top()).arg(s.right()).arg(s.bottom()).arg(s.width()).arg(s.height()).toLatin1().constData());
}
template<> inline char *toString(const QPointF &p)
{
- return tqstrdup(QString::fromLatin1("QPointF(%1,%2)").arg(p.x()).arg(p.y()).toLatin1().constData());
+ return qstrdup(QString::fromLatin1("QPointF(%1,%2)").arg(p.x()).arg(p.y()).toLatin1().constData());
}
template<> inline char *toString(const QSizeF &s)
{
- return tqstrdup(QString::fromLatin1("QSizeF(%1x%2)").arg(s.width()).arg(s.height()).toLatin1().constData());
+ return qstrdup(QString::fromLatin1("QSizeF(%1x%2)").arg(s.width()).arg(s.height()).toLatin1().constData());
}
template<> inline char *toString(const QRectF &s)
{
- return tqstrdup(QString::fromLatin1("QRectF(%1,%2 %5x%6) (bottomright %3,%4)").arg(s.left()).arg(s.top()).arg(s.right()).arg(s.bottom()).arg(s.width()).arg(s.height()).toLatin1().constData());
+ return qstrdup(QString::fromLatin1("QRectF(%1,%2 %5x%6) (bottomright %3,%4)").arg(s.left()).arg(s.top()).arg(s.right()).arg(s.bottom()).arg(s.width()).arg(s.height()).toLatin1().constData());
}
template<> inline char *toString(const QUrl &uri)
{
- return tqstrdup(uri.toEncoded().constData());
+ return qstrdup(uri.toEncoded().constData());
}
template<> inline char *toString(const QVariant &v)
@@ -168,7 +168,7 @@ template<> inline char *toString(const QVariant &v)
}
vstring.append(')');
- return tqstrdup(vstring.constData());
+ return qstrdup(vstring.constData());
}
#ifndef QTEST_NO_SPECIALIZATIONS
diff --git a/qtinterface/qt4/Qt/qtestaccessible.h b/qtinterface/qt4/Qt/qtestaccessible.h
index ff9f79f..e9ad6fb 100644
--- a/qtinterface/qt4/Qt/qtestaccessible.h
+++ b/qtinterface/qt4/Qt/qtestaccessible.h
@@ -90,7 +90,7 @@ public:
{
if (!instance()) {
instance() = new QTestAccessibility;
- tqAddPostRoutine(cleanup);
+ qAddPostRoutine(cleanup);
}
}
static void cleanup()
@@ -127,19 +127,19 @@ private:
static void rootObjectHandler(QObject *object)
{
- // tqDebug("rootObjectHandler called %p", object);
+ // qDebug("rootObjectHandler called %p", object);
if (object) {
QApplication* app = qobject_cast<QApplication*>(object);
if ( !app )
- tqWarning("QTEST_ACCESSIBILITY: root Object is not a QApplication!");
+ qWarning("QTEST_ACCESSIBILITY: root Object is not a QApplication!");
} else {
- tqWarning("QTEST_ACCESSIBILITY: root Object called with 0 pointer");
+ qWarning("QTEST_ACCESSIBILITY: root Object called with 0 pointer");
}
}
static void updateHandler(QObject *o, int c, QAccessible::Event e)
{
- // tqDebug("updateHandler called: %p %d %d", o, c, (int)e);
+ // qDebug("updateHandler called: %p %d %d", o, c, (int)e);
eventList().append(QTestAccessibilityEvent(o, c, (int)e));
}
diff --git a/qtinterface/tqt.h.cmake b/qtinterface/tqt.h.cmake
index 492429f..c56998b 100644
--- a/qtinterface/tqt.h.cmake
+++ b/qtinterface/tqt.h.cmake
@@ -954,8 +954,8 @@ Boston, MA 02110-1301, USA.
#endif
-#define tqSystemWarning tqSystemWarning
-#define tqSuppressObsoleteWarnings tqSuppressObsoleteWarnings
+#define tqSystemWarning qSystemWarning
+#define tqSuppressObsoleteWarnings qSuppressObsoleteWarnings
#define tqmoc moc
#define TQMOC MOC
@@ -1000,62 +1000,62 @@ Boston, MA 02110-1301, USA.
#define tqApp qApp
-#define tqAddPostRoutine tqAddPostRoutine
-#define tqWarning tqWarning
-#define tqSharedBuild tqSharedBuild
-#define tqNetworkProtocolRegister tqNetworkProtocolRegister
-#define tqDebug tqDebug
-#define tqCompress tqCompress
-#define tqFatal tqFatal
-#define tqSqlDriverExtDict tqSqlDriverExtDict
-#define tqSqlOpenExtDict tqSqlOpenExtDict
-#define tqInitNetworkProtocols tqInitNetworkProtocols
-#define tqSuppressObsoleteWarnings tqSuppressObsoleteWarnings
-#define tqChecksum tqChecksum
-#define tqRemovePostRoutine tqRemovePostRoutine
-#define tqInstallPath tqInstallPath
-#define tqObsolete tqObsolete
-#define tqVersion tqVersion
-#define tqSystemWarning tqSystemWarning
-#define tqSysInfo tqSysInfo
-
-#define tqmemmove tqmemmove
-#define tqstrncpy tqstrncpy
-#define tqstrdup tqstrdup
-#define tqstrnicmp tqstrnicmp
-#define tqstricmp tqstricmp
-
-#define tqt_get_application_thread_id tqt_get_application_thread_id
-#define tqt_x_user_time tqt_x_user_time
-#define tqt_xget_temp_gc tqt_xget_temp_gc
-#define tqt_has_xft tqt_has_xft
-#define tqt_modal_state tqt_modal_state
-#define tqt_check_pointer tqt_check_pointer
-#define tqt_preliminary_signal_spy tqt_preliminary_signal_spy
-#define tqt_wm_take_focus tqt_wm_take_focus
-#define tqt_global_mutexpool tqt_global_mutexpool
-#define tqt_xdisplay tqt_xdisplay
-#define tqt_resolve_symlinks tqt_resolve_symlinks
-#define tqt_qclipboard_bailout_hack tqt_qclipboard_bailout_hack
-#define tqt_x_time tqt_x_time
-#define tqt_wm_delete_window tqt_wm_delete_window
-#define tqt_qheader_label_return_null_strings tqt_qheader_label_return_null_strings
-#define tqt_xscreen tqt_xscreen
-#define tqt_setAccelAutoShortcuts tqt_setAccelAutoShortcuts
-#define tqt_sm_client_id tqt_sm_client_id
-#define tqt_set_table_clipper_enabled tqt_set_table_clipper_enabled
-#define tqt_hebrew_keyboard_hack tqt_hebrew_keyboard_hack
-#define tqt_use_native_dialogs tqt_use_native_dialogs
-#define tqt_generate_epsf tqt_generate_epsf
-#define tqt_xget_readonly_gc tqt_xget_readonly_gc
-#define tqt_use_xrender tqt_use_xrender
-#define tqt_set_x11_event_filter tqt_set_x11_event_filter
-#define tqt_xrootwin tqt_xrootwin
-#define tqt_wm_protocols tqt_wm_protocols
-#define tqt_ftp_filename_codec tqt_ftp_filename_codec
-#define tqt_window_role tqt_window_role
-#define tqt_tab_all_widgets tqt_tab_all_widgets
-#define tqt_wm_state tqt_wm_state
+#define tqAddPostRoutine qAddPostRoutine
+#define tqWarning qWarning
+#define tqSharedBuild qSharedBuild
+#define tqNetworkProtocolRegister qNetworkProtocolRegister
+#define tqDebug qDebug
+#define tqCompress qCompress
+#define tqFatal qFatal
+#define tqSqlDriverExtDict qSqlDriverExtDict
+#define tqSqlOpenExtDict qSqlOpenExtDict
+#define tqInitNetworkProtocols qInitNetworkProtocols
+#define tqSuppressObsoleteWarnings qSuppressObsoleteWarnings
+#define tqChecksum qChecksum
+#define tqRemovePostRoutine qRemovePostRoutine
+#define tqInstallPath qInstallPath
+#define tqObsolete qObsolete
+#define tqVersion qVersion
+#define tqSystemWarning qSystemWarning
+#define tqSysInfo qSysInfo
+
+#define tqmemmove qmemmove
+#define tqstrncpy qstrncpy
+#define tqstrdup qstrdup
+#define tqstrnicmp qstrnicmp
+#define tqstricmp qstricmp
+
+#define tqt_get_application_thread_id qt_get_application_thread_id
+#define tqt_x_user_time qt_x_user_time
+#define tqt_xget_temp_gc qt_xget_temp_gc
+#define tqt_has_xft qt_has_xft
+#define tqt_modal_state qt_modal_state
+#define tqt_check_pointer qt_check_pointer
+#define tqt_preliminary_signal_spy qt_preliminary_signal_spy
+#define tqt_wm_take_focus qt_wm_take_focus
+#define tqt_global_mutexpool qt_global_mutexpool
+#define tqt_xdisplay qt_xdisplay
+#define tqt_resolve_symlinks qt_resolve_symlinks
+#define tqt_qclipboard_bailout_hack qt_qclipboard_bailout_hack
+#define tqt_x_time qt_x_time
+#define tqt_wm_delete_window qt_wm_delete_window
+#define tqt_qheader_label_return_null_strings qt_qheader_label_return_null_strings
+#define tqt_xscreen qt_xscreen
+#define tqt_setAccelAutoShortcuts qt_setAccelAutoShortcuts
+#define tqt_sm_client_id qt_sm_client_id
+#define tqt_set_table_clipper_enabled qt_set_table_clipper_enabled
+#define tqt_hebrew_keyboard_hack qt_hebrew_keyboard_hack
+#define tqt_use_native_dialogs qt_use_native_dialogs
+#define tqt_generate_epsf qt_generate_epsf
+#define tqt_xget_readonly_gc qt_xget_readonly_gc
+#define tqt_use_xrender qt_use_xrender
+#define tqt_set_x11_event_filter qt_set_x11_event_filter
+#define tqt_xrootwin qt_xrootwin
+#define tqt_wm_protocols qt_wm_protocols
+#define tqt_ftp_filename_codec qt_ftp_filename_codec
+#define tqt_window_role qt_window_role
+#define tqt_tab_all_widgets qt_tab_all_widgets
+#define tqt_wm_state qt_wm_state
#endif
@@ -1218,7 +1218,7 @@ Boston, MA 02110-1301, USA.
#define tqMakePair qMakePair
#define tqt_ucm_query_verification_data qt_ucm_query_verification_data
-#define tqmemmove tqmemmove
+#define tqmemmove qmemmove
#define TQ_ControlElement ControlElement
#define TQ_ComplexControl ComplexControl
@@ -1544,10 +1544,10 @@ class QUObject;
#define TQNoBrush Qt::NoBrush
#define QMetaData QMetaMethod
-#define tqt_xdisplay QX11Info::display
-#define tqt_xrootwin QX11Info::appRootWindow
-#define tqt_xscreen QX11Info::appScreen
-#define tqt_xget_temp_gc QPaintDevice::tqt_xget_temp_gc
+#define qt_xdisplay QX11Info::display
+#define qt_xrootwin QX11Info::appRootWindow
+#define qt_xscreen QX11Info::appScreen
+#define qt_xget_temp_gc QPaintDevice::qt_xget_temp_gc
#define TickSetting TickPosition
#define ButtonState Qt::ButtonState
#define qHeapSort tqHeapSort
diff --git a/qtinterface/tqt4/Qt/qglobal.h b/qtinterface/tqt4/Qt/qglobal.h
index af3d17f..d5bf293 100644
--- a/qtinterface/tqt4/Qt/qglobal.h
+++ b/qtinterface/tqt4/Qt/qglobal.h
@@ -488,7 +488,7 @@ namespace QT_NAMESPACE {}
# if __GNUC__ < 3 || (__GNUC__ == 3 && __GNUC_MINOR__ <= 3)
# define Q_NO_TEMPLATE_FRIENDS
# endif
-/* Apple's GCC 3.1 chokes on our streaming tqDebug() */
+/* Apple's GCC 3.1 chokes on our streaming qDebug() */
# if defined(Q_OS_DARWIN) && __GNUC__ == 3 && (__GNUC_MINOR__ >= 1 && __GNUC_MINOR__ < 3)
# define Q_BROKEN_DEBUG_STREAM
# endif
@@ -1522,15 +1522,15 @@ public:
#endif
};
-Q_CORE_EXPORT const char *tqVersion();
-Q_CORE_EXPORT bool tqSharedBuild();
+Q_CORE_EXPORT const char *qVersion();
+Q_CORE_EXPORT bool qSharedBuild();
#if defined(Q_OS_MAC)
inline int qMacVersion() { return QSysInfo::MacintoshVersion; }
#endif
#ifdef QT3_SUPPORT
-inline QT3_SUPPORT bool tqSysInfo(int *wordSize, bool *bigEndian)
+inline QT3_SUPPORT bool qSysInfo(int *wordSize, bool *bigEndian)
{
*wordSize = QSysInfo::WordSize;
*bigEndian = (QSysInfo::ByteOrder == QSysInfo::BigEndian);
@@ -1593,13 +1593,13 @@ inline void qUnused(T &x) { (void)x; }
# define qPrintable(string) (string).toLocal8Bit().constData()
#endif
-Q_CORE_EXPORT void tqDebug(const char *, ...) /* print debug message */
+Q_CORE_EXPORT void qDebug(const char *, ...) /* print debug message */
#if defined(Q_CC_GNU) && !defined(__INSURE__)
__attribute__ ((format (printf, 1, 2)))
#endif
;
-Q_CORE_EXPORT void tqWarning(const char *, ...) /* print warning message */
+Q_CORE_EXPORT void qWarning(const char *, ...) /* print warning message */
#if defined(Q_CC_GNU) && !defined(__INSURE__)
__attribute__ ((format (printf, 1, 2)))
#endif
@@ -1612,14 +1612,14 @@ Q_CORE_EXPORT void qCritical(const char *, ...) /* print critical message */
__attribute__ ((format (printf, 1, 2)))
#endif
;
-Q_CORE_EXPORT void tqFatal(const char *, ...) /* print fatal message and exit */
+Q_CORE_EXPORT void qFatal(const char *, ...) /* print fatal message and exit */
#if defined(Q_CC_GNU) && !defined(__INSURE__)
__attribute__ ((format (printf, 1, 2)))
#endif
;
#ifdef QT3_SUPPORT
-Q_CORE_EXPORT QT3_SUPPORT void tqSystemWarning(const char *msg, int code = -1);
+Q_CORE_EXPORT QT3_SUPPORT void qSystemWarning(const char *msg, int code = -1);
#endif /* QT3_SUPPORT */
Q_CORE_EXPORT void qErrnoWarning(int code, const char *msg, ...);
Q_CORE_EXPORT void qErrnoWarning(const char *msg, ...);
@@ -1631,25 +1631,25 @@ Q_CORE_EXPORT void qErrnoWarning(const char *msg, ...);
/*
Forward declarations only.
- In order to use the tqDebug() stream, you must #include<QDebug>
+ In order to use the qDebug() stream, you must #include<QDebug>
*/
class QDebug;
class QNoDebug;
#ifndef QT_NO_DEBUG_STREAM
-Q_CORE_EXPORT_INLINE QDebug tqDebug();
-Q_CORE_EXPORT_INLINE QDebug tqWarning();
+Q_CORE_EXPORT_INLINE QDebug qDebug();
+Q_CORE_EXPORT_INLINE QDebug qWarning();
Q_CORE_EXPORT_INLINE QDebug qCritical();
#else
-inline QNoDebug tqDebug();
+inline QNoDebug qDebug();
#endif
-#define QT_NO_QDEBUG_MACRO while (false) tqDebug
+#define QT_NO_QDEBUG_MACRO while (false) qDebug
#ifdef QT_NO_DEBUG_OUTPUT
-# define tqDebug QT_NO_QDEBUG_MACRO
+# define qDebug QT_NO_QDEBUG_MACRO
#endif
-#define QT_NO_QWARNING_MACRO while (false) tqWarning
+#define QT_NO_QWARNING_MACRO while (false) qWarning
#ifdef QT_NO_WARNING_OUTPUT
-# define tqWarning QT_NO_QWARNING_MACRO
+# define qWarning QT_NO_QWARNING_MACRO
#endif
@@ -1677,7 +1677,7 @@ Q_CORE_EXPORT void qt_assert_x(const char *where, const char *what, const char *
# endif
#endif
-Q_CORE_EXPORT void tqt_check_pointer(const char *, int);
+Q_CORE_EXPORT void qt_check_pointer(const char *, int);
#ifndef QT_NO_EXCEPTIONS
Q_CORE_EXPORT void qBadAlloc();
@@ -1687,7 +1687,7 @@ Q_CORE_EXPORT void qBadAlloc();
# if defined(QT_NO_DEBUG)
# define Q_CHECK_PTR(p) qt_noop();
# else
-# define Q_CHECK_PTR(p) do {if(!(p))tqt_check_pointer(__FILE__,__LINE__);} while (0)
+# define Q_CHECK_PTR(p) do {if(!(p))qt_check_pointer(__FILE__,__LINE__);} while (0)
# endif
#else
# define Q_CHECK_PTR(p) do { if (!(p)) qBadAlloc(); } while (0)
@@ -1731,8 +1731,8 @@ typedef void (*QtMsgHandler)(QtMsgType, const char *);
Q_CORE_EXPORT QtMsgHandler qInstallMsgHandler(QtMsgHandler);
#ifdef QT3_SUPPORT
-inline QT3_SUPPORT void tqSuppressObsoleteWarnings(bool = true) {}
-inline QT3_SUPPORT void tqObsolete(const char *, const char * = 0, const char * = 0) {}
+inline QT3_SUPPORT void qSuppressObsoleteWarnings(bool = true) {}
+inline QT3_SUPPORT void qObsolete(const char *, const char * = 0, const char * = 0) {}
#endif
#if defined(QT_NO_THREAD)
@@ -1942,7 +1942,7 @@ static inline bool qIsNull(float f)
#ifdef Q_FULL_TEMPLATE_INSTANTIATION
# define Q_DUMMY_COMPARISON_OPERATOR(C) \
bool operator==(const C&) const { \
- tqWarning(#C"::operator==(const "#C"&) was called"); \
+ qWarning(#C"::operator==(const "#C"&) was called"); \
return false; \
}
#else
@@ -2404,15 +2404,15 @@ Q_CORE_EXPORT int qrand();
#ifndef QT_PRODUCT_LICENSE
# define QT_PRODUCT_LICENSE QLibraryInfo::licensedProducts()
#endif
-QT3_SUPPORT Q_CORE_EXPORT const char *tqInstallPath();
-QT3_SUPPORT Q_CORE_EXPORT const char *tqInstallPathDocs();
-QT3_SUPPORT Q_CORE_EXPORT const char *tqInstallPathHeaders();
-QT3_SUPPORT Q_CORE_EXPORT const char *tqInstallPathLibs();
-QT3_SUPPORT Q_CORE_EXPORT const char *tqInstallPathBins();
-QT3_SUPPORT Q_CORE_EXPORT const char *tqInstallPathPlugins();
-QT3_SUPPORT Q_CORE_EXPORT const char *tqInstallPathData();
-QT3_SUPPORT Q_CORE_EXPORT const char *tqInstallPathTranslations();
-QT3_SUPPORT Q_CORE_EXPORT const char *tqInstallPathSysconf();
+QT3_SUPPORT Q_CORE_EXPORT const char *qInstallPath();
+QT3_SUPPORT Q_CORE_EXPORT const char *qInstallPathDocs();
+QT3_SUPPORT Q_CORE_EXPORT const char *qInstallPathHeaders();
+QT3_SUPPORT Q_CORE_EXPORT const char *qInstallPathLibs();
+QT3_SUPPORT Q_CORE_EXPORT const char *qInstallPathBins();
+QT3_SUPPORT Q_CORE_EXPORT const char *qInstallPathPlugins();
+QT3_SUPPORT Q_CORE_EXPORT const char *qInstallPathData();
+QT3_SUPPORT Q_CORE_EXPORT const char *qInstallPathTranslations();
+QT3_SUPPORT Q_CORE_EXPORT const char *qInstallPathSysconf();
#endif
#if defined(Q_OS_SYMBIAN)
diff --git a/qtinterface/tqt4/Qt/qpaintdevice.h b/qtinterface/tqt4/Qt/qpaintdevice.h
index 208e3d1..98157db 100644
--- a/qtinterface/tqt4/Qt/qpaintdevice.h
+++ b/qtinterface/tqt4/Qt/qpaintdevice.h
@@ -95,7 +95,7 @@ public:
#elif defined(Q_WS_X11)
virtual Qt::HANDLE handle() const;
virtual Qt::HANDLE x11RenderHandle() const;
- static GC tqt_xget_temp_gc( int scrn, bool monochrome );
+ static GC qt_xget_temp_gc( int scrn, bool monochrome );
#elif defined(Q_WS_MAC)
virtual Qt::HANDLE handle() const;
#elif defined(Q_WS_QWS)
diff --git a/qtinterface/qt4/Qt/qbytearray.h b/qtinterface/qt4/Qt/qbytearray.h
index 8250408..f7c0cd3 100644
--- a/qtinterface/qt4/Qt/qbytearray.h
+++ b/qtinterface/qt4/Qt/qbytearray.h
@@ -62,7 +62,7 @@ QT_MODULE(Core)
Safe and portable C string functions; extensions to standard string.h
*****************************************************************************/
-Q_CORE_EXPORT char *tqstrdup(const char *);
+Q_CORE_EXPORT char *qstrdup(const char *);
inline uint qstrlen(const char *str)
{ return str ? uint(strlen(str)) : 0; }
@@ -78,7 +78,7 @@ inline uint qstrnlen(const char *str, uint maxlen)
}
Q_CORE_EXPORT char *qstrcpy(char *dst, const char *src);
-Q_CORE_EXPORT char *tqstrncpy(char *dst, const char *src, uint len);
+Q_CORE_EXPORT char *qstrncpy(char *dst, const char *src, uint len);
Q_CORE_EXPORT int qstrcmp(const char *str1, const char *str2);
Q_CORE_EXPORT int qstrcmp(const QByteArray &str1, const QByteArray &str2);
@@ -91,15 +91,15 @@ inline int qstrncmp(const char *str1, const char *str2, uint len)
return (str1 && str2) ? strncmp(str1, str2, len)
: (str1 ? 1 : (str2 ? -1 : 0));
}
-Q_CORE_EXPORT int tqstricmp(const char *, const char *);
-Q_CORE_EXPORT int tqstrnicmp(const char *, const char *, uint len);
+Q_CORE_EXPORT int qstricmp(const char *, const char *);
+Q_CORE_EXPORT int qstrnicmp(const char *, const char *, uint len);
// implemented in qvsnprintf.cpp
Q_CORE_EXPORT int qvsnprintf(char *str, size_t n, const char *fmt, va_list ap);
Q_CORE_EXPORT int qsnprintf(char *str, size_t n, const char *fmt, ...);
#ifdef QT3_SUPPORT
-inline QT3_SUPPORT void *tqmemmove(void *dst, const void *src, uint len)
+inline QT3_SUPPORT void *qmemmove(void *dst, const void *src, uint len)
{ return memmove(dst, src, len); }
inline QT3_SUPPORT uint cstrlen(const char *str)
{ return uint(strlen(str)); }
@@ -111,9 +111,9 @@ inline QT3_SUPPORT int cstrncmp(const char *str1, const char *str2, uint len)
{ return strncmp(str1,str2,len); }
#endif
-// tqChecksum: Internet checksum
+// qChecksum: Internet checksum
-Q_CORE_EXPORT quint16 tqChecksum(const char *s, uint len);
+Q_CORE_EXPORT quint16 qChecksum(const char *s, uint len);
class QByteRef;
class QString;
@@ -578,10 +578,10 @@ Q_CORE_EXPORT QDataStream &operator>>(QDataStream &, QByteArray &);
#endif
#ifndef QT_NO_COMPRESS
-Q_CORE_EXPORT QByteArray tqCompress(const uchar* data, int nbytes, int compressionLevel = -1);
+Q_CORE_EXPORT QByteArray qCompress(const uchar* data, int nbytes, int compressionLevel = -1);
Q_CORE_EXPORT QByteArray qUncompress(const uchar* data, int nbytes);
-inline QByteArray tqCompress(const QByteArray& data, int compressionLevel = -1)
-{ return tqCompress(reinterpret_cast<const uchar *>(data.constData()), data.size(), compressionLevel); }
+inline QByteArray qCompress(const QByteArray& data, int compressionLevel = -1)
+{ return qCompress(reinterpret_cast<const uchar *>(data.constData()), data.size(), compressionLevel); }
inline QByteArray qUncompress(const QByteArray& data)
{ return qUncompress(reinterpret_cast<const uchar*>(data.constData()), data.size()); }
#endif
diff --git a/qtinterface/tqt4/Qt/qbytearray.h b/qtinterface/tqt4/Qt/qbytearray.h
index 754c891..9ee2be3 100644
--- a/qtinterface/tqt4/Qt/qbytearray.h
+++ b/qtinterface/tqt4/Qt/qbytearray.h
@@ -62,7 +62,7 @@ QT_MODULE(Core)
Safe and portable C string functions; extensions to standard string.h
*****************************************************************************/
-Q_CORE_EXPORT char *tqstrdup(const char *);
+Q_CORE_EXPORT char *qstrdup(const char *);
inline uint qstrlen(const char *str)
{ return str ? uint(strlen(str)) : 0; }
@@ -78,7 +78,7 @@ inline uint qstrnlen(const char *str, uint maxlen)
}
Q_CORE_EXPORT char *qstrcpy(char *dst, const char *src);
-Q_CORE_EXPORT char *tqstrncpy(char *dst, const char *src, uint len);
+Q_CORE_EXPORT char *qstrncpy(char *dst, const char *src, uint len);
Q_CORE_EXPORT int qstrcmp(const char *str1, const char *str2);
Q_CORE_EXPORT int qstrcmp(const QByteArray &str1, const QByteArray &str2);
@@ -91,15 +91,15 @@ inline int qstrncmp(const char *str1, const char *str2, uint len)
return (str1 && str2) ? strncmp(str1, str2, len)
: (str1 ? 1 : (str2 ? -1 : 0));
}
-Q_CORE_EXPORT int tqstricmp(const char *, const char *);
-Q_CORE_EXPORT int tqstrnicmp(const char *, const char *, uint len);
+Q_CORE_EXPORT int qstricmp(const char *, const char *);
+Q_CORE_EXPORT int qstrnicmp(const char *, const char *, uint len);
// implemented in qvsnprintf.cpp
Q_CORE_EXPORT int qvsnprintf(char *str, size_t n, const char *fmt, va_list ap);
Q_CORE_EXPORT int qsnprintf(char *str, size_t n, const char *fmt, ...);
#ifdef QT3_SUPPORT
-inline QT3_SUPPORT void *tqmemmove(void *dst, const void *src, uint len)
+inline QT3_SUPPORT void *qmemmove(void *dst, const void *src, uint len)
{ return memmove(dst, src, len); }
inline QT3_SUPPORT uint cstrlen(const char *str)
{ return uint(strlen(str)); }
@@ -111,9 +111,9 @@ inline QT3_SUPPORT int cstrncmp(const char *str1, const char *str2, uint len)
{ return strncmp(str1,str2,len); }
#endif
-// tqChecksum: Internet checksum
+// qChecksum: Internet checksum
-Q_CORE_EXPORT quint16 tqChecksum(const char *s, uint len);
+Q_CORE_EXPORT quint16 qChecksum(const char *s, uint len);
class QByteRef;
class QString;
@@ -583,10 +583,10 @@ Q_CORE_EXPORT QDataStream &operator>>(QDataStream &, QByteArray &);
#endif
#ifndef QT_NO_COMPRESS
-Q_CORE_EXPORT QByteArray tqCompress(const uchar* data, int nbytes, int compressionLevel = -1);
+Q_CORE_EXPORT QByteArray qCompress(const uchar* data, int nbytes, int compressionLevel = -1);
Q_CORE_EXPORT QByteArray qUncompress(const uchar* data, int nbytes);
-inline QByteArray tqCompress(const QByteArray& data, int compressionLevel = -1)
-{ return tqCompress(reinterpret_cast<const uchar *>(data.constData()), data.size(), compressionLevel); }
+inline QByteArray qCompress(const QByteArray& data, int compressionLevel = -1)
+{ return qCompress(reinterpret_cast<const uchar *>(data.constData()), data.size(), compressionLevel); }
inline QByteArray qUncompress(const QByteArray& data)
{ return qUncompress(reinterpret_cast<const uchar*>(data.constData()), data.size()); }
#endif